@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import httplib2
 import lxml.html
 
@@ -108,4 +106,20 @@ def save_realtime_title(filename="libertytimes_realtime_title", append=False,
         
         fo.close()
         
-    return 1
\ No newline at end of file
+    return 1
+
+def save_realtime_title_csv(filename="libretytimes_realtime_title.csv", append=False,
+                            pages=5, encoding="UTF-8"):
+    
+    title_info = get_realtime_title(pages = 5, encoding = encoding)
+    
+    if append:
+        pass
+    else:
+        fo = open(filename, "w")
+        fo.write('"title", "time", "url"\n')
+        for info in title_info:
+            fo.write('"%s", "%s", "%s"\n' %
+                     (info['title'], info['time'], info['url']))
+        
+        fo.close()
\ No newline at end of file
